==> ruby-puppet-0.20.1.tgz: lib/ruby/site_ruby/1.8/puppet/provider/package/darwinport.rb <==
Puppet::Type.type(:package).provide :darwinport do
    desc "Package management using DarwinPorts on OS X."

    commands :port => "/opt/local/bin/port"
    confine :operatingsystem => "Darwin"

    def self.eachpkgashash
        # list out all of the packages
        open("| #{command(:port)} list installed") { |process|
            regex = %r{(\S+)\s+@(\S+)\s+(\S+)}
            fields = [:name, :ensure, :location]
            hash = {}

            # now turn each returned line into a package object
            process.each { |line|
                hash.clear

                if match = regex.match(line)
                    fields.zip(match.captures) { |field,value|
                        hash[field] = value
                    }

                    hash.delete :location
                    yield hash.dup
                else
                    raise Puppet::DevError,
                        "Failed to match dpkg line %s" % line
                end
            }
        }
    end

    def self.list
        packages = []

        eachpkgashash do |hash|
            pkg = Puppet.type(:package).installedpkg(hash)
            packages << pkg
        end

        return packages
    end

    def install
        should = @model.should(:ensure)

        # Seems like you can always say 'upgrade'
        port "upgrade #{@model[:name]}"
    end

    def query
        version = nil
        self.class.eachpkgashash do |hash|
            if hash[:name] == @model[:name]
                return hash
            end
        end

        return nil
    end

    def latest
        info = port "search '^#{@model[:name]}$' 2>/dev/null"

        if $? != 0 or info =~ /^Error/
            return nil
        end

        ary = info.split(/\s+/)
        version = ary[2].sub(/^@/, '')

        return version
    end

    def uninstall
        port "uninstall #{@model[:name]}"
    end

    def update
        return install()
    end
end

# $Id: darwinport.rb 1627 2006-09-19 06:03:11Z luke $

==> ruby-puppet-0.22.4p0.tgz: lib/ruby/site_ruby/1.8/puppet/provider/package/darwinport.rb <==
Puppet::Type.type(:package).provide :darwinport do
    desc "Package management using DarwinPorts on OS X."

    commands :port => "/opt/local/bin/port"
    confine :operatingsystem => "Darwin"

    def self.eachpkgashash
        # list out all of the packages
        open("| #{command(:port)} list installed") { |process|
            regex = %r{(\S+)\s+@(\S+)\s+(\S+)}
            fields = [:name, :ensure, :location]
            hash = {}

            # now turn each returned line into a package object
            process.each { |line|
                hash.clear

                if match = regex.match(line)
                    fields.zip(match.captures) { |field,value|
                        hash[field] = value
                    }

                    hash.delete :location
                    hash[:provider] = self.name
                    yield hash.dup
                else
                    raise Puppet::DevError,
                        "Failed to match dpkg line %s" % line
                end
            }
        }
    end

    def self.list
        packages = []

        eachpkgashash do |hash|
            pkg = Puppet.type(:package).installedpkg(hash)
            packages << pkg
        end

        return packages
    end

    def install
        should = @model.should(:ensure)

        # Seems like you can always say 'upgrade'
        output = port "upgrade", @model[:name]
        if output =~ /^Error: No port/
            raise Puppet::ExecutionFailure, "Could not find package %s" % @model[:name]
        end
    end

    def query
        version = nil
        self.class.eachpkgashash do |hash|
            if hash[:name] == @model[:name]
                return hash
            end
        end

        return nil
    end

    def latest
        info = port :search, "^#{@model[:name]}$"

        if $? != 0 or info =~ /^Error/
            return nil
        end

        ary = info.split(/\s+/)
        version = ary[2].sub(/^@/, '')

        return version
    end

    def uninstall
        port :uninstall, @model[:name]
    end

    def update
        return install()
    end
end

# $Id: darwinport.rb 2052 2007-01-05 17:09:04Z luke $
